leetx_parser
============

.. image:: https://img.shields.io/pypi/v/leetx_parser.svg
    :target: https://pypi.python.org/pypi/leetx_parser
    :alt: Latest PyPI version

.. image:: https://www.travis-ci.org/evgeny1602/leetx_parser.png
   :target: https://www.travis-ci.org/evgeny1602/leetx_parser
   :alt: Latest Travis CI build status

Finds magnet links for TV show episodes

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------
GNU General Public License v3.0

Authors
-------

`leetx_parser` was written by `Evgeny Lobanov <evgeny1602@gmail.com>`_.
